==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/WebNavDrawerItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavDrawerItemDescription } from "./WebNavDrawerItemDescription";
/**
 * @hidden
 */
var WebNavDrawerItemDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebNavDrawerItemDescriptionMetadata, _super);
    function WebNavDrawerItemDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebNavDrawerItemDescriptionMetadata.b = function (a) {
        if (WebNavDrawerItemDescriptionMetadata.a == null) {
            WebNavDrawerItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebNavDrawerItemDescriptionMetadata.c(WebNavDrawerItemDescriptionMetadata.a);
        }
        if (a.g(WebNavDrawerItemDescriptionMetadata.a)) {
            return;
        }
        a.s(WebNavDrawerItemDescriptionMetadata.a);
    };
    WebNavDrawerItemDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:NavDrawerItem");
        a.item("Disabled", "Boolean");
        a.item("Active", "Boolean");
    };
    WebNavDrawerItemDescriptionMetadata.d = function (a) {
        WebNavDrawerItemDescriptionMetadata.b(a);
        a.u("WebNavDrawerItem", function () { return new WebNavDrawerItemDescription(); });
        a.t("WebNavDrawerItem", WebNavDrawerItemDescriptionMetadata.a);
    };
    WebNavDrawerItemDescriptionMetadata.$t = markType(WebNavDrawerItemDescriptionMetadata, 'WebNavDrawerItemDescriptionMetadata');
    WebNavDrawerItemDescriptionMetadata.a = null;
    return WebNavDrawerItemDescriptionMetadata;
}(Base));
export { WebNavDrawerItemDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebNavDrawerItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavDrawerItemDescription } from "./WebNavDrawerItemDescription";
/**
 * @hidden
 */
var WebNavDrawerItemDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebNavDrawerItemDescriptionMetadata, _super);
    function WebNavDrawerItemDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebNavDrawerItemDescriptionMetadata.b = function (a) {
        if (WebNavDrawerItemDescriptionMetadata.a == null) {
            WebNavDrawerItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebNavDrawerItemDescriptionMetadata.c(WebNavDrawerItemDescriptionMetadata.a);
        }
        if (a.j(WebNavDrawerItemDescriptionMetadata.a)) {
            return;
        }
        a.y(WebNavDrawerItemDescriptionMetadata.a);
    };
    WebNavDrawerItemDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:NavDrawerItem");
        a.item("__tagNameWC", "String:igc-nav-drawer-item");
        a.item("Disabled", "Boolean");
        a.item("Active", "Boolean");
    };
    WebNavDrawerItemDescriptionMetadata.d = function (a) {
        WebNavDrawerItemDescriptionMetadata.b(a);
        a.aa("WebNavDrawerItem", function () { return new WebNavDrawerItemDescription(); });
        a.z("WebNavDrawerItem", WebNavDrawerItemDescriptionMetadata.a);
    };
    WebNavDrawerItemDescriptionMetadata.$t = markType(WebNavDrawerItemDescriptionMetadata, 'WebNavDrawerItemDescriptionMetadata');
    WebNavDrawerItemDescriptionMetadata.a = null;
    return WebNavDrawerItemDescriptionMetadata;
}(Base));
export { WebNavDrawerItemDescriptionMetadata };
